raytraverse.formatter
==========================================================

Formatter
---------------------------

.. autoclass:: raytraverse.formatter.Formatter
    :members:
    :undoc-members:
    :show-inheritance:

RadianceFormatter
---------------------------

.. autoclass:: raytraverse.formatter.RadianceFormatter
    :members:
    :undoc-members:
    :show-inheritance:

